import _extends from "@babel/runtime/helpers/esm/extends";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";

var __rest = this && this.__rest || function (s, e) {
  var t = {};

  for (var p in s) {
    if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0) t[p] = s[p];
  }

  if (s != null && typeof Object.getOwnPropertySymbols === "function") for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
    if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i])) t[p[i]] = s[p[i]];
  }
  return t;
};

import { ItemGroup } from 'rc-menu';
import * as React from 'react';
import { forwardRef, useImperativeHandle, useMemo, useRef } from 'react';
import { TinyColor } from '@ctrl/tinycolor';
import InternalMenu from './menu';
import { SiderContext } from '../layout/Sider';
import MenuDivider from './MenuDivider';
import Item from './MenuItem';
import SubMenu from './SubMenu';
import { ConfigProvider } from '..';
import { useToken } from '../theme';
var ThemedMenu = /*#__PURE__*/forwardRef(function (_a, ref) {
  var _a$theme = _a.theme,
      theme = _a$theme === void 0 ? 'light' : _a$theme,
      rest = __rest(_a, ["theme"]);

  var menuRef = useRef(null);

  var _useToken = useToken(),
      _useToken2 = _slicedToArray(_useToken, 2),
      token = _useToken2[1];

  useImperativeHandle(ref, function () {
    return {
      focus: function focus(options) {
        var _a;

        (_a = menuRef.current) === null || _a === void 0 ? void 0 : _a.focus(options);
      },
      menu: menuRef.current
    };
  });
  var colorTextLightSolid = token.colorTextLightSolid,
      colorTextDescription = token.colorTextDescription,
      colorPrimary = token.colorPrimary,
      colorError = token.colorError,
      colorErrorHover = token.colorErrorHover;
  var darkThemeToken = useMemo(function () {
    if (theme === 'dark') {
      return {
        colorItemText: new TinyColor(colorTextLightSolid).setAlpha(0.65).toRgbString(),
        colorItemTextHover: colorTextLightSolid,
        colorGroupTitle: colorTextDescription,
        colorItemTextSelected: colorTextLightSolid,
        colorItemBg: '#001529',
        colorSubItemBg: '#000c17',
        colorItemBgActive: 'transparent',
        colorItemBgSelected: colorPrimary,
        colorActiveBarWidth: 0,
        colorActiveBarHeight: 0,
        colorActiveBarBorderSize: 0,
        // Disabled
        colorItemTextDisabled: new TinyColor(colorTextLightSolid).setAlpha(0.25).toRgbString(),
        // Danger
        colorDangerItemText: colorError,
        colorDangerItemTextHover: colorErrorHover,
        colorDangerItemTextSelected: colorTextLightSolid,
        colorDangerItemBgActive: colorError,
        colorDangerItemBgSelected: colorError
      };
    }

    return {};
  }, [theme]);
  return /*#__PURE__*/React.createElement(ConfigProvider, {
    theme: {
      override: {
        Menu: darkThemeToken
      }
    }
  }, /*#__PURE__*/React.createElement(SiderContext.Consumer, null, function (context) {
    return /*#__PURE__*/React.createElement(InternalMenu, _extends({
      ref: menuRef
    }, rest, context));
  }));
});
var Menu = ThemedMenu;
Menu.Divider = MenuDivider;
Menu.Item = Item;
Menu.SubMenu = SubMenu;
Menu.ItemGroup = ItemGroup;
export default Menu;